#define MESSAGES_VERSION "2.7.8"
#define CANT_FIND_PRINTCAP_FILE 0
#define USAGE_FOR 1
#define CANNOT_INSTALL_XPM_ICON 2
#define NO_MATCH_FOUND_FOR_VISUAL 3
#define BAD_VISUAL_TYPE_SPECIFICATION 4
#define YOUR_CANVAS_DEPTH_IS_THAT_MANY_BITS 5
#define SEPARATOR_STRIP_ONE 6
#define WARNING_ONE 7
#define SEPARATOR_STRIP_TWO 8
#define WARNING_TWO_A 9
#define WARNING_TWO_B 10
#define WARNING_THREE_A 11
#define WARNING_THREE_B 12
#define WARNING_THREE_C 13
#define NO_FILE_NAME_SUPPLIED 14
#define UNABLE_TO_GET_REGION 15
#define UNABLE_TO_CREATE_IMAGE 16
#define UNABLE_TO_CREATE_IMAGE_FOR_SAVING 17
#define ERROR_SAVING_FILE 18
#define NO_REGION_SELECTED_PRESENTLY 19
#define NO_SUCH_FILE_OR_DIRECTORY 20
#define UNABLE_TO_OPEN_INPUT_FILE 21
#define IMAGE_FORMATS 22
#define END_IMAGE_FORMATS 39
#define POSITION 39
#define VALUE 40
#define RED_COLOR 41
#define GREEN_COLOR 42
#define BLUE_COLOR 43
#define RED_VARIANCE 44
#define GREEN_VARIANCE 45
#define BLUE_VARIANCE 46
#define SPACING 47
#define ENTER_DESIRED_SNAP_SPACING 48
#define LEVELS 49
#define NUMBER_OF_UNDO_LEVELS 50
#define IMAGE_NUMBER 51
#define RECALL_AN_IMAGE 52
#define REMOVE_AN_IMAGE 53
#define ZOOM 54
#define CHANGE_ZOOM_FACTOR_FOR_IMAGE 55
#define ANGLE_IN_DEGREES 56
#define ENTER_DESIRED_ROTATION 57
#define ENTER_TWOBYTWO_MATRIX_ENTRIES 58
#define ENTER_POINTS 59
#define MUST_BE_ODD 60
#define ENTER_MASK_SIZE_FOR_OIL_PAINT_EFFECT 61
#define ENTER_MASK_SIZE_FOR_SMOOTHING_EFFECT 62
#define ENTER_DESIRED_NOISE_VARIANCE 63
#define DISTANCE_PIXELS 64
#define ENTER_THE_DESIRED_SPREAD_DISTANCE 65
#define WIDTH_X_HEIGHT_OR_SINGLE_NUMBER 66
#define ENTER_DESIRED_MEGAPIXEL_SIZE 67
#define ENTER_MASK_SIZE_FOR_DESPECKLE_FILTER 68
#define BLACK_LEVEL 69
#define WHITE_LEVEL 70
#define ENTER_LEVELS_FOR_CONTRAST_ADJUSTMENT 71
#define ENTER_THRESHOLD_FOR_SOLARIZE_FILTER 72
#define ENTER_DESIRED_SHIFT_FOR_RGB_COMPONENTS 73
#define RED_SHIFT 74
#define GREEN_SHIFT 75
#define BLUE_SHIFT 76
#define ENTER_DESIRED_NUMBER_OF_COLORS 77
#define SIZE_WIDTH 78
#define SIZE_HEIGHT 79
#define SIZE_ZOOM 80
#define ENTER_DESIRED_IMAGE_SIZE 81
#define LINE_WIDTH 82
#define ENTER_DESIRED_LINE_WIDTH 83
#define ENTER_DESIRED_DASH_STYLE 84
#define DASH_STYLE 85
#define OPACITY 86
#define ENTER_THE_DESIRED_BRUSH_PARAMETERS 87
#define DENSITY 88
#define ENTER_THE_DESIRED_FRACTAL_DENSITY 89
#define DYNAMIC_WIDTH 90
#define DYNAMIC_MASS 91
#define DYNAMIC_DRAG 92
#define ENTER_THE_DESIRED_DYNAMIC_PENCIL_PARAMETERS 93
#define SPRAY_RADIUS 94
#define SPRAY_DENSITY 95
#define SPRAY_RATE 96
#define ENTER_THE_DESIRED_SPRAY_PARAMETERS 97
#define ARROWHEAD_TYPE 98
#define ARROWHEAD_SIZE 99
#define ARROWHEAD_ANGLE 100
#define ENTER_THE_DESIRED_ARROWHEAD_PARAMETERS 101
#define BOX_ROUND_CORNER_ABSOLUTE_SIZE 102
#define BOX_ROUND_CORNER_RELATIVE_SIZE 103
#define ENTER_THE_DESIRED_ROUND_CORNER_SIZE 104
#define NUMBER_OF_SIDES_OF_POLYGON 105
#define STARLIKE_POLYGON_INNER_RATIO 106
#define ENTER_THE_DESIRED_SPECIAL_POLYGON_PARAMETERS 107
#define GRADIENT_ANGLE 108
#define GRADIENT_PAD 109
#define GRADIENT_HORIZONTAL_OFFSET 110
#define GRADIENT_VERTICAL_OFFSET 111
#define GRADIENT_STEPS 112
#define ENTER_THE_DESIRED_GRADIENT_FILL_PARAMETERS 113
#define PATTERN_WIDTH 114
#define PATTERN_HEIGHT 115
#define ENTER_THE_DESIRED_PATTERN_SIZE 116
#define YOU_MUST_HAVE_AT_LEAST_ONE_ENTRY 117
#define NO_INFORMATION_TO_SAVE 118
#define UNABLE_TO_OPEN_FILE 119
#define UNABLE_TO_OPEN_FILE_FOR_WRITING 120
#define OVERWRITE_FILE 121
#define UNSAVED_CHANGES_WISH_TO_QUIT 122
#define UNSAVED_CHANGES_WISH_TO_CLOSE 123
#define UNSAVED_CHANGES_WISH_TO_REVERT 124
#define RESIZING_WARNING_CANNOT_BE_UNDONE 125
#define AUTOCROP_WARNING_CANNOT_BE_UNDONE 126
#define ARE_YOU_SURE_YOU_WANT_TO_CROP_THE_IMAGE_TO_THE_SIZE_OF_THE_REGION 127
#define BAD_SNAP_SPACING 128
#define BAD_NUMBER_OF_UNDO_LEVELS 129
#define INVALID_ZOOM 130
#define INVALID_MASK_SIZE 131
#define INVALID_NOISE_VARIANCE 132
#define INVALID_SPREAD_DISTANCE 133
#define INVALID_PIXEL_SIZE 134
#define INVALID_WHITE_LEVEL 135
#define INVALID_BLACK_LEVEL 136
#define INVALID_SOLARIZATION_THRESHOLD 137
#define INVALID_RGB_PERCENTAGES 138
#define INVALID_NUMBER_OF_COLORS 139
#define UNABLE_TO_CREATE_PAINT_WINDOW_WITH_IMAGE 140
#define FILE_WRITTEN 141
#define FILE_SENT_TO_PRINTER 142
#define INVALID_WIDTH_MUST_BE_GREATER_THAN_ZERO 143
#define DASH_IS_GIVEN_BY_ALTERNATING_SUCH_CHARACTERS 144
#define OPACITY_SHOULD_BE_BETWEEN_ZERO_AND_HUNDRED_PERCENT 145
#define WIDTH_SHOULD_BE_BETWEEN_ONE_AND_ONE_HUNDRED 146
#define MASS_SHOULD_BE_BETWEEN_TEN_AND_TWO_THOUSAND 147
#define DRAG_SHOULD_BE_BETWEEN_ZERO_AND_FIFTY 148
#define RADIUS_SHOULD_BE_BETWEEN_ONE_AND_ONE_HUNDRED 149
#define DENSITY_SHOULD_BE_BETWEEN_ONE_AND_FIVE_HUNDRED 150
#define RATE_SHOULD_BE_BETWEEN_ONE_AND_FIVE_HUNDRED 151
#define TYPE_SHOULD_BE_BETWEEN_ONE_AND_MAXTYPE 152
#define SIZE_SHOULD_BE_BETWEEN_ONE_AND_ONE_THOUSAND 153
#define ANGLE_SHOULD_BE_BETWEEN_ZERO_AND_SIXTY 154
#define NUMBER_OF_SIDES_SHOULD_BE_BETWEEN_THREE_AND_ONE_HUNDRED 155
#define BOX_ROUND_CORNER_ABSOLUTE_SIZE_SHOULD_BE_BETWEEN_ZERO_AND_ONE_THOUSAND 156
#define BOX_ROUND_CORNER_RELATIVE_SIZE_SHOULD_BE_BETWEEN_ZERO_AND_ONE 157
#define BOX_ROUND_CORNER_ABSOLUTE_AND_RELATIVE_SIZE_CANNOT_BE_BOTH_POSITIVE 158
#define INNER_RATIO_SHOULD_BE_BETWEEN_ZERO_AND_ONE 159
#define HORIZONTAL_OFFSET_SHOULD_BE_BETWEEN_PLUS_MINUS_HUNDRED_PERCENT 160
#define VERTICAL_OFFSET_SHOULD_BE_BETWEEN_PLUS_MINUS_HUNDRED_PERCENT 161
#define PAD_SHOULD_BE_BETWEEN_PLUS_MINUS_FOURTY_NINE_PERCENT 162
#define ANGLE_SHOULD_BE_BETWEEN_PLUS_MINUS_THREE_HUNDRED_SIXTY_DEGREES 163
#define NUMBER_OF_STEPS_SHOULD_BE_BETWEEN_ONE_AND_THREE_HUNDRED 164
#define FONT_SELECT_DESIRED_PROPERTIES 165
#define UNABLE_TO_LOAD_REQUESTED_FONT 166
#define YOU_MUST_FIRST_COMPILE_A_C_SCRIPT 167
#define C_SCRIPT_SUCCESSFULLY_COMPILED_AND_LINKED 168
#define C_SCRIPT_COULD_NOT_BE_COMPILED_OR_LINKED 169
#define INVALID_WIDTH 170
#define INVALID_HEIGHT 171
#define INVALID_WIDTH_OR_HEIGHT_MUST_BE_GREATER_THAN_ZERO 172
#define INVALID_WIDTH_OR_HEIGHT_MUST_BE_LESS_THAN_HUNDRED_TWENTY_NINE 173
#define INVALID_WIDTH_OR_HEIGHT_MUST_BE_BETWEEN_ZERO_AND_TWO_HUNDRED_FIFTY_SIX 174
#define DIRECTORIES 175
#define FILES 176
#define OPEN_FILE_NAMED 177
#define SAVE_IN_FILE 178
#define LOAD_FROM_FILE 179
#define IMAGE_NUMBER_OUT_OF_RANGE 180
#define OUT_OF_MEMORY 181
#define UNABLE_TO_ALLOCATE_SUFFICIENT_COLOR_ENTRIES 182
#define TRY_EXITING_OTHER_COLOR_INTENSIVE_APPLICATIONS 183
#define SHOULDNT_HAPPEN 184
#define ERROR_IN_XINTERNATOM 185
#define CANNOT_GRAB_POINTER 186
#define INSUFFICIENT_RESOURCES_FOR_OPERATION 187
#define PROBABLY_NOT_ENOUGH_MEMORY_TO_ALLOCATE_PIXMAP 188
#define ERROR_CODE 189
#define UNKNOWN_IMAGE_FORMAT 190
#define OUT_OF_MEMORY_ALLOCATING_A_ROW 191
#define OUT_OF_MEMORY_ALLOCATING_AN_ARRAY 192
#define READ_ERROR 193
#define WRITE_ERROR 194
#define A_FILE_READ_ERROR_OCCURRED_AT_SOME_POINT 195
#define A_FILE_WRITE_ERROR_OCCURRED_AT_SOME_POINT 196
#define JUNK_IN_FILE_WHERE_BITS_SHOULD_BE 197
#define READ_ERROR_READING_MAGIC_NUMBER 198
#define JUNK_IN_FILE_WHERE_AN_INTEGER_SHOULD_BE 199
#define CANT_HAPPEN 200
#define MAXVAL_IS_TOO_LARGE 201
#define BAD_MAGIC_NUMBER_NOT_A_PPM_PGM_OR_PBM_FILE 202
#define OUT_OF_MEMORY_COMPUTING_HASH_TABLE 203
#define OUT_OF_MEMORY_ALLOCATING_HASH_TABLE 204
#define OUT_OF_MEMORY_GENERATING_HISTOGRAM 205
#define SAME_COLOR_FOUND_TWICE 206
#define COLORHIST_OUT_OF_MEMORY 207
#define FATAL_LIBPNG_ERROR_LONGJMP_CALLED_WHILE_READING 208
#define FATAL_LIBPNG_ERROR_LONGJMP_CALLED_WHILE_WRITING 209
#define ERROR_PLTE_CHUNK_NOT_FOUND_IN_PALETTE_IMAGE 210
#define STRIPPING_48_BIT_RGB_IMAGE_TO_24_BITS 211
#define STRIPPING_16_BIT_GRAYSCALE_IMAGE_TO_8_BITS 212
#define STRIPPING_64_BIT_RGBA_IMAGE_TO_32_BITS 213
#define STRIPPING_32_BIT_GRAY_ALPHA_IMAGE_TO_16_BITS 214
#define UNKNOWN_PNG_IMAGE_TYPE 215
#define READPNG_CANT_ALLOCATE_MEMORY_FOR_ROW_POINTERS_1 216
#define READPNG_CANT_ALLOCATE_MEMORY_FOR_ROW_POINTERS_2 217
#define UNABLE_TO_ALLOCATE_TEMPORARY_STORAGE_FOR_ALPHA_IMAGE 218
#define READPNG_UNABLE_TO_MALLOC_PNG_DATA 219
#define WRITEPNG_CANT_USE_ALPHA_MASK_WITH_COLORMAPPED_IMAGE 220
#define WRITEPNG_SORRY_CANT_WRITE_ALPHA_IMAGES_YET 221
#define WRITEPNG_CANT_ALLOCATE_MEMORY_FOR_ROW_POINTERS 222
#define XPAINT_FATAL_LIBPNG_ERROR 223
#define XPAINT_EXTREMELY_FATAL_LIBPNG_ERROR 224
#define END_MESSAGES 225

extern String *msgText;
extern int msgNum;
